# .md referencing

Below is an overview of reference style links in markdown but for those in a rush, lets provide the quick version for our use case:

Create your citation using 2 sets of square brackets. The first goes around the keyword that is a link. The second goes immediately after and is a label (make it unique.) To make this fit the uwe Harvard style you can write the author name and date in parentheses and wrap them in `[]`.
At the end of your document, place `[]:` with the unique label you provided in the citation inside of the braces and then paste the UWE Harvard reference after the colon. Build the reference [here](https://www.uwe.ac.uk/study/study-support/study-skills/referencing/referencing-tools/harvard-reference-builder?gad_source=1&gclid=CjwKCAiAvJarBhA1EiwAGgZl0PX7Wv_Q390KWIi94s9jHiJRn0CAd_6vRt1vvOtyT77uDWiABu9sRRoC8RQQAvD_BwE&gclsrc=aw.ds) and then copy and past the output.

 

Follow this example:
To reference my latest paper (as an example), you might consider the following example:

Do not reference my paper, it is not related to this module [(Renney, 2022)][1]

[1]: Renney, Nathan, N., Gaster, B., Mitchell, T. and Renney, H. (2022) Studying How Digital Luthiers Choose Their Tools. _Proceedings of the 2022 Chi Conference on Human Factors in Computing Systems_ [online].

The raw markdown for this looks like this:
```md
Do not reference my paper, it is not related to this module [(Renney, 2022)][1]

[1]: Renney, Nathan, N., Gaster, B., Mitchell, T. and Renney, H. (2022) Studying How Digital Luthiers Choose Their Tools. _Proceedings of the 2022 Chi Conference on Human Factors in Computing Systems_ [online].
```



# general guide:

### Reference-style Links[](https://www.markdownguide.org/basic-syntax/#reference-style-links)

Reference-style links are a special kind of link that make URLs easier to display and read in Markdown. Reference-style links are constructed in two parts: the part you keep inline with your text and the part you store somewhere else in the file to keep the text easy to read.

#### Formatting the First Part of the Link[](https://www.markdownguide.org/basic-syntax/#formatting-the-first-part-of-the-link)

The first part of a reference-style link is formatted with two sets of brackets. The first set of brackets surrounds the text that should appear linked. The second set of brackets displays a label used to point to the link you’re storing elsewhere in your document.

Although not required, you can include a space between the first and second set of brackets. The label in the second set of brackets is not case sensitive and can include letters, numbers, spaces, or punctuation.

This means the following example formats are roughly equivalent for the first part of the link:

- `[hobbit-hole][1]`
- `[hobbit-hole] [1]`

#### Formatting the Second Part of the Link[](https://www.markdownguide.org/basic-syntax/#formatting-the-second-part-of-the-link)

The second part of a reference-style link is formatted with the following attributes:

1. The label, in brackets, followed immediately by a colon and at least one space (e.g., `[label]:` ).
2. The URL for the link, which you can optionally enclose in angle brackets.
3. The optional title for the link, which you can enclose in double quotes, single quotes, or parentheses.

This means the following example formats are all roughly equivalent for the second part of the link:

- `[1]: https://en.wikipedia.org/wiki/Hobbit#Lifestyle`
- `[1]: https://en.wikipedia.org/wiki/Hobbit#Lifestyle "Hobbit lifestyles"`
- `[1]: https://en.wikipedia.org/wiki/Hobbit#Lifestyle 'Hobbit lifestyles'`
- `[1]: https://en.wikipedia.org/wiki/Hobbit#Lifestyle (Hobbit lifestyles)`
- `[1]: <https://en.wikipedia.org/wiki/Hobbit#Lifestyle> "Hobbit lifestyles"`
- `[1]: <https://en.wikipedia.org/wiki/Hobbit#Lifestyle> 'Hobbit lifestyles'`
- `[1]: <https://en.wikipedia.org/wiki/Hobbit#Lifestyle> (Hobbit lifestyles)`

You can place this second part of the link anywhere in your Markdown document. Some people place them immediately after the paragraph in which they appear while other people place them at the end of the document (like endnotes or footnotes).

#### An Example Putting the Parts Together[](https://www.markdownguide.org/basic-syntax/#an-example-putting-the-parts-together)

Say you add a URL as a [standard URL link](https://www.markdownguide.org/basic-syntax/#links) to a paragraph and it looks like this in Markdown:

```
In a hole in the ground there lived a hobbit. Not a nasty, dirty, wet hole, filled with the ends
of worms and an oozy smell, nor yet a dry, bare, sandy hole with nothing in it to sit down on or to
eat: it was a [hobbit-hole](https://en.wikipedia.org/wiki/Hobbit#Lifestyle "Hobbit lifestyles"), and that means comfort.
```

Though it may point to interesting additional information, the URL as displayed really doesn’t add much to the existing raw text other than making it harder to read. To fix that, you could format the URL like this instead:

```
In a hole in the ground there lived a hobbit. Not a nasty, dirty, wet hole, filled with the ends
of worms and an oozy smell, nor yet a dry, bare, sandy hole with nothing in it to sit down on or to
eat: it was a [hobbit-hole][1], and that means comfort.

[1]: <https://en.wikipedia.org/wiki/Hobbit#Lifestyle> "Hobbit lifestyles"
```