# Disclaimer

All examples are taken from a previous year, with different scenarios and some different content. Remember you must focus your work around the concepts we have explored! Use the examples to inspire your writing, not as a template! Note that these projects are certainly not a perfect example either, they are a representation of average work (according to the previous report format).

remember that the correlated document for these videos is available on the ctap-resources repo

# General Points

Remember we want to see snippets of code, not one large piece of code (to share larger programs, include the file(s) in the code directory)

References should use UWE Harvard referencing. Use the builder here: [reference builder tool](https://www.uwe.ac.uk/study/study-support/study-skills/referencing/referencing-tools/harvard-reference-builder?gad_source=1&gclid=CjwKCAiAvJarBhA1EiwAGgZl0AghoaofhWLTn5G-Wc4RaHOqlm0SK0gAnWLPtQ_xuKcgjZwYqNnK_hoC3LsQAvD_BwE&gclsrc=aw.ds)

# Background

The background section is one where you can write up and explore problems related to the scenario you have selected.

- Good place for some references
	- Similar solutions
	- Papers or posts that help describe the motivations or approach laid out in the scenario

- The background section should provide information that helps your marker understand what you are doing.

The goal is to contextualise your report in this section.

*Example:*

> The Computational thinking assessment has tasked students to create and submit a group portfolio of work in which individual as well as group work is documented. The students have been provided with 6 case study in which they must choose one that they are interested in. The students need to form groups of 2-4 that were working on the same case study. These group will assess each other’s solution in part 2 of the assessment In Case Study 2 Bristol City Council has asked for a solution to help evaluate the impact of private diesel vehicles in the Bristol CAZ. A Clean Air Zone is a new mechanism proposed by the government to help cities tackle increasing air pollution. Bristol aims to be carbon neutral by 2030[7]. To achieve this goal Bristol is implementing a CAZ within the city centre to help reduce the amount of NO2 in the local atmosphere as air pollution mixtures represented by NO2 have an effect on non-accidental and circulatory mortality[3]. The UK government has set limits to air pollution within cities. Therefore, Bristol is making changes to meet the requirements.

# Decomposition

[Slides](https://nrenney.bitbucket.io/ctap/week10-1/#/)

The decomposition section indicates the problem you are working on by identifying one  problem in the scenario and breaking it down into the subproblems that make it up. 
In this section discuss the following:
- identifying problems that are implied by the scenario
- ensure that problems are brief and high level and only consider issues, not how they are addressed
- ensure that sub problems are the things that contribute to the problem it is derived from
	- ask how are these related
	- does solving the sub problem actual help solve the parent problem

Focus on creating a tree that breaks down multiple problems down at least 3 layers. You should then work further on one of these branches considering many sub problems involved in a particular solution. This should be the branch you try to come back to and develop throughout the report.

*Example:*

> John would like a solution that can automatically identify diesel fuel private and public vehicles. Providing the system with this information will allow estimations to be made on potential impacts. Similarly, distinguishing between private or public vehicles i.e. (buses, taxis) or private vehicles is necessary to identify what group is having the biggest impact and evaluate what services are needed. This is important to help minimise the social/ethical impact all parties involved. For example there are additional benefits to public transport[ref]. Finding an appropriate method of displaying collected information. As John described, Bristol City Council has an analyst to evaluate impacts. The analyst is important to take an in-depth investigation into the data and provide quantitative information from that. The quantitative estimation can be used to go back to Bristol City Council.
> Recording the traffic trends with a method that can later preform analysis and provide estimation on such data. John has suggested that the actual carbon footprint on different times of the day/year would be beneficial for estimations of impacts. The analysis can be used to make conclusions on the most appropriate rules/regulations for the Clean Air Zone. This could involve alternate solutions for example driving restriction prohibits drivers from using their vehicles on given weekdays, based on the last digits of their vehicles’ license plates. License plate-based driving restrictions have been widely used as a method to reduce urban air pollution and traffic congestion in developing countries[ref]. Without making consideration the environment could also be negatively affected as megacities greatly aggravates the health impacts of polluted air, yet it may also provide an opportunity to mitigate climate change, if implemented air quality policies are designed to also reduce global warming [ref].

# Requirements

[Related Slides](https://nrenney.bitbucket.io/ctap/week10-2/#/)

Follow the lecture and content for this week! Beyond these suggestions you can also talk about motivations, cost benefit analysis, requirements validation and the workflow of defining requirements. That said, start with the following points as these are the core ones for marking, build on the rest if you have space!

## Feasibility
Requirements should start by exploring the **feasibility** of solving your problem. Start with obvious points, for example the existence of existing similar solutions implies feasibility. For example, there are many phones apps so we can assume that a phone app is feasible to create. The prolific use of wireless technologies such as wifi and bluetooth demonstrate that wireless communication is achievable. On the other hand, the ability to communicate instantaneously is not feasible as we know of no way of information to be transmitted faster than light. These are extreme/ trivial examples, so try to explore and discuss the practicality of problems related to your scenario.
## Functional requirements
list out and discuss (considering things like difficulty and priority) the functional requirements.

Remember that functional requirements are like verbs, what should users be able to do.
- What does the user need?
- What are the features?
- What are the actions to interact with the system?

## NON FUNCTIONAL REQUIREMENTS

- How should things happen?
- Are there technical details that make something possible or are desirable?

Concerns attributes like speed, security, reliability, data integrity, etc.
	
# Models

Covered in week 11 
[Slides](https://nrenney.bitbucket.io/ctap/week11-1/#/)
[Slides](https://nrenney.bitbucket.io/ctap/week11-2/#/)

This section should cover the use of models. Focus on behavioural models (such as flow diagram) and data models (such as ERD diagrams) first individually. You may then write about how these relate. In this section you should identify and explore what parts of a problem you are attempting to model and what information is perhaps left out for clarity?

This section is worth 15% so ensure that you develop these ideas well. You may wish to relate your diagrams to code either here or in one of the code sections.

You might also develop multiple models for different problems or relate two models (for example where a predefined process in a flow diagram is defined by a second flow diagram).

While diagrams are useful for models you should ensure that you are also supporting these with a written exploration and rationale to support the choices and approaches that are used and to justify what is omitted.

You might also discuss or even use some of these [alternative models](https://nrenney.bitbucket.io/ctap/week11-1/#/16) which where introduced in the lecture (for extra credit).
# Code design

Depending on your work in previous sections, this may be short or removed entirely. This section represents the need to consider some ideas on how you might structure your code.

You should consider the translation of many of your diagrams (for example, ERD or flow diagrams) as part of this and if you decided to locate these and discuss this in those sections then that is fine. The important thing is that your report talks about the representation of certain ideas in code. Examples include using a class to structure data or using functions to capture predefined processes from a flow diagram.

You should use content from across the entire module (as there are examples of converting ideas into code most weeks) and you should be sure to add a few lines about each decision or approach. Why is boolean algebra a good fit for a certain problem or why break a problem up into functions.

Week 15 lecture 1 also considers a number of high level principles that may influence these points and provide ideas for discussion.

Covered throughout the module from early weeks up to the end. See week 13 for video that covered converting a flow diagram into code!

[Algorithms Slides](https://nrenney.bitbucket.io/ctap/week12-2/#/)

Error handling could go here or potentially in testing.

# Abstractions and patterns

Week 12
[Slides](https://nrenney.bitbucket.io/ctap/week12-1/#/)

Abstractions should be you identifying existing abstractions that are helpful and/or creating your own abstractions to represent generic parts of your solution. 
> Remember, abstractions can be both data and behaviour and so relate heavily to the processes of modelling!

Data:
- why represent some data as a list?
- why have you used sets, tuples or dictionaries? Why not?
- How have you grouped data in objects like a class?
- How do these classes relate?

Behaviour:
- What operations are made available on the objects you have? For example, why is it useful that lists can be iterated over?
- What is the value of modifying values with a function?
- How do you organise what things are moved into a function? (DRY principle/reuse?)

More generally, what patterns have you recognised in your problem?

How do we create an abstraction that provides us a better interface to work with? 
> Think of the car example where the pedals and wheel give us a way to move, without needing to think about the underlying engine directly



*Example:*

> Abstraction is the process of identifying and extracting the key features and functionalities of a system while hiding unnecessary details. By abstracting away irrelevant information, we can create a high-level representation that captures the essence of the problem at hand. This approach facilitates the development of scalable and adaptable solutions. To monitor cars in a clean air zone, we employ abstraction to create a solution that efficiently collects and analyzes relevant data. We abstract the car monitoring process into three main components: data collection, data analysis, and reporting. Abstraction allows us to focus on the essential data points required for monitoring cars in a clean air zone. We abstract away the specific details of individual cars and instead concentrate on collecting data such as vehicle emissions, license plate numbers, and timestamps. This abstraction simplifies the data collection process and ensures the necessary information is captured accurately. Abstraction plays a crucial role in analyzing the collected data. By abstracting the data into meaningful categories, such as emission levels and vehicle types, we can identify patterns and trends. This abstraction enables us to develop algorithms and models that can efficiently process and analyze large volumes of data, providing valuable insights into the overall air quality and compliance levels. 



# Coding

This heading is somewhat redundant and is here for legacy reasons (code used to be included as screen grabs.) Coding should be included as snippets throughout the report and/or as files in the `portfolio/code` folder.



# Testing

Week 14 - 2
[Slides](https://nrenney.bitbucket.io/ctap/week14-2/#/)

Here we should document and identify the tests that support your solution in the context of your scenario. 

Demonstrate the testing of a function as was discussed and demonstrated in week 14. Provide the unit tests and provide a rationale for what cases you have tested.

Then move on to discuss what and why you may test using integration and end to end tests. You might consider formatting some of these in the style of the test plan that is demonstrated on page 93 of Beechers book.

# Evaluation 

The evaluation section should primarily read as reflection of how you carried out your work and how you applied computational thinking. Documents some of the key take aways and ideas that developed and discuss how these will inform the way you approach problem solving in the future. Were objectives achieved? How effectiveness, correct and usable were your ideas and the code you presented. Did you get a small simulation of any problem to present a solution?
What were the strengths and weaknesses of your solution. Where there any ways to extend or improve what you did? You can also comment here on social, legal, professional and ethical issues and if they have been (or could be) addressed (if you have not yet covered this in the background for example).